==> Ice-3.0.0.tar.gz: Ice-3.0.0/src/IceGrid/Grammar.h <==
/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     ICE_GRID_HELP = 258,
     ICE_GRID_EXIT = 259,
     ICE_GRID_APPLICATION = 260,
     ICE_GRID_NODE = 261,
     ICE_GRID_SERVER = 262,
     ICE_GRID_ADAPTER = 263,
     ICE_GRID_PING = 264,
     ICE_GRID_LOAD = 265,
     ICE_GRID_ADD = 266,
     ICE_GRID_REMOVE = 267,
     ICE_GRID_LIST = 268,
     ICE_GRID_SHUTDOWN = 269,
     ICE_GRID_STRING = 270,
     ICE_GRID_START = 271,
     ICE_GRID_STOP = 272,
     ICE_GRID_PATCH = 273,
     ICE_GRID_SIGNAL = 274,
     ICE_GRID_STDOUT = 275,
     ICE_GRID_STDERR = 276,
     ICE_GRID_DESCRIBE = 277,
     ICE_GRID_STATE = 278,
     ICE_GRID_PID = 279,
     ICE_GRID_ENDPOINTS = 280,
     ICE_GRID_ACTIVATION = 281,
     ICE_GRID_OBJECT = 282,
     ICE_GRID_FIND = 283,
     ICE_GRID_SHOW = 284,
     ICE_GRID_COPYING = 285,
     ICE_GRID_WARRANTY = 286,
     ICE_GRID_DIFF = 287,
     ICE_GRID_UPDATE = 288,
     ICE_GRID_INSTANTIATE = 289,
     ICE_GRID_TEMPLATE = 290,
     ICE_GRID_SERVICE = 291,
     ICE_GRID_ENABLE = 292,
     ICE_GRID_DISABLE = 293
   };
#endif
#define ICE_GRID_HELP 258
#define ICE_GRID_EXIT 259
#define ICE_GRID_APPLICATION 260
#define ICE_GRID_NODE 261
#define ICE_GRID_SERVER 262
#define ICE_GRID_ADAPTER 263
#define ICE_GRID_PING 264
#define ICE_GRID_LOAD 265
#define ICE_GRID_ADD 266
#define ICE_GRID_REMOVE 267
#define ICE_GRID_LIST 268
#define ICE_GRID_SHUTDOWN 269
#define ICE_GRID_STRING 270
#define ICE_GRID_START 271
#define ICE_GRID_STOP 272
#define ICE_GRID_PATCH 273
#define ICE_GRID_SIGNAL 274
#define ICE_GRID_STDOUT 275
#define ICE_GRID_STDERR 276
#define ICE_GRID_DESCRIBE 277
#define ICE_GRID_STATE 278
#define ICE_GRID_PID 279
#define ICE_GRID_ENDPOINTS 280
#define ICE_GRID_ACTIVATION 281
#define ICE_GRID_OBJECT 282
#define ICE_GRID_FIND 283
#define ICE_GRID_SHOW 284
#define ICE_GRID_COPYING 285
#define ICE_GRID_WARRANTY 286
#define ICE_GRID_DIFF 287
#define ICE_GRID_UPDATE 288
#define ICE_GRID_INSTANTIATE 289
#define ICE_GRID_TEMPLATE 290
#define ICE_GRID_SERVICE 291
#define ICE_GRID_ENABLE 292
#define ICE_GRID_DISABLE 293




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
typedef int YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

==> Ice-3.1.0.tar.gz: Ice-3.1.0/src/IceGrid/Grammar.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     ICE_GRID_HELP = 258,
     ICE_GRID_EXIT = 259,
     ICE_GRID_APPLICATION = 260,
     ICE_GRID_NODE = 261,
     ICE_GRID_SERVER = 262,
     ICE_GRID_ADAPTER = 263,
     ICE_GRID_PING = 264,
     ICE_GRID_LOAD = 265,
     ICE_GRID_ADD = 266,
     ICE_GRID_REMOVE = 267,
     ICE_GRID_LIST = 268,
     ICE_GRID_SHUTDOWN = 269,
     ICE_GRID_STRING = 270,
     ICE_GRID_START = 271,
     ICE_GRID_STOP = 272,
     ICE_GRID_PATCH = 273,
     ICE_GRID_SIGNAL = 274,
     ICE_GRID_STDOUT = 275,
     ICE_GRID_STDERR = 276,
     ICE_GRID_DESCRIBE = 277,
     ICE_GRID_STATE = 278,
     ICE_GRID_PID = 279,
     ICE_GRID_ENDPOINTS = 280,
     ICE_GRID_ACTIVATION = 281,
     ICE_GRID_OBJECT = 282,
     ICE_GRID_FIND = 283,
     ICE_GRID_SHOW = 284,
     ICE_GRID_COPYING = 285,
     ICE_GRID_WARRANTY = 286,
     ICE_GRID_DIFF = 287,
     ICE_GRID_UPDATE = 288,
     ICE_GRID_INSTANTIATE = 289,
     ICE_GRID_TEMPLATE = 290,
     ICE_GRID_SERVICE = 291,
     ICE_GRID_ENABLE = 292,
     ICE_GRID_DISABLE = 293
   };
#endif
/* Tokens.  */
#define ICE_GRID_HELP 258
#define ICE_GRID_EXIT 259
#define ICE_GRID_APPLICATION 260
#define ICE_GRID_NODE 261
#define ICE_GRID_SERVER 262
#define ICE_GRID_ADAPTER 263
#define ICE_GRID_PING 264
#define ICE_GRID_LOAD 265
#define ICE_GRID_ADD 266
#define ICE_GRID_REMOVE 267
#define ICE_GRID_LIST 268
#define ICE_GRID_SHUTDOWN 269
#define ICE_GRID_STRING 270
#define ICE_GRID_START 271
#define ICE_GRID_STOP 272
#define ICE_GRID_PATCH 273
#define ICE_GRID_SIGNAL 274
#define ICE_GRID_STDOUT 275
#define ICE_GRID_STDERR 276
#define ICE_GRID_DESCRIBE 277
#define ICE_GRID_STATE 278
#define ICE_GRID_PID 279
#define ICE_GRID_ENDPOINTS 280
#define ICE_GRID_ACTIVATION 281
#define ICE_GRID_OBJECT 282
#define ICE_GRID_FIND 283
#define ICE_GRID_SHOW 284
#define ICE_GRID_COPYING 285
#define ICE_GRID_WARRANTY 286
#define ICE_GRID_DIFF 287
#define ICE_GRID_UPDATE 288
#define ICE_GRID_INSTANTIATE 289
#define ICE_GRID_TEMPLATE 290
#define ICE_GRID_SERVICE 291
#define ICE_GRID_ENABLE 292
#define ICE_GRID_DISABLE 293




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
typedef int YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif
